@@ -43,18 +43,18 @@ audio::audio()
 {
 	a = new audioPrivate;
 	a->server = Arts::Reference("global:Arts_SoundServerV2");
-	a->fileRef.setAutoDelete( TRUE );
+	a->fileRef.setAutoDelete( true );
 	if( a->server.isNull() )
 	{
-		a->enabled = FALSE;
+		a->enabled = false;
 		kdWarning() << "audio::audio: Can not create Arts::SoundServerV2" << endl;
 	}
 	else
 	{
-		a->enabled = TRUE;
+		a->enabled = true;
 		a->playObjectFactory = Arts::Reference("global:Arts_PlayObjectFactory");
 	}
-	a->firstTime = TRUE;
+	a->firstTime = true;
 }
 audio::~audio()
 {
@@ -118,7 +118,7 @@ void audio::setTheme( const TQString &newTheme )
 		kdWarning() << "audio::setTheme: Can not access theme.conf from " << newTheme << endl;
 		return;
 	}
-	themeConfig = new KSimpleConfig( configFile, TRUE );
+	themeConfig = new KSimpleConfig( configFile, true );
 
 	/* Read the details about this theme */
 	themeConfig->setGroup( "General" );
@@ -142,7 +142,7 @@ void audio::setTheme( const TQString &newTheme )
 	prepFile( a->theme + themeConfig->readEntry("DrawOffer"), SND_DRAW_OFFER );
 	prepFile( a->theme + themeConfig->readEntry("Say"), SND_SAY );
 	prepFile( a->theme + themeConfig->readEntry("Promote"), SND_PROMOTE );
-	a->firstTime = FALSE;
+	a->firstTime = false;
 
 	delete themeConfig;
 	TDEIO::NetAccess::removeTempFile( configFile );
@@ -156,7 +156,7 @@ void audio::prepFile( const TQString &source, const int &ref )
 		return;
 
 	dest = new KTempFile( TQString(), source.right(4), 700 );
-	dest->setAutoDelete( TRUE );
+	dest->setAutoDelete( true );
 	filename = dest->name();
 
 	if( !TDEIO::NetAccess::download( source, filename ) )
