@@ -29,14 +29,14 @@ board_2d::board_2d(TQWidget *parent, const char *name, resource *Rsrc, logic *Lg
 {
 	updateX1 = updateY1 = 4000;
 	updateX2 = updateY2 = -4000;
-	init = TRUE;
+	init = true;
 	premoveFrom = Null;
 	premoveTo = Null;
 	DragSprite = NULL;
-	lastMoveWasDrag = FALSE;
+	lastMoveWasDrag = false;
 	cache = myResource->pixCache;
-	int size = 8 + ( 1 * ( myResource->ThemeBorder == TRUE ) );
-	sprites.setAutoDelete( TRUE );
+	int size = 8 + ( 1 * ( myResource->ThemeBorder == true ) );
+	sprites.setAutoDelete( true );
 
 	/* Setup Pixmaps */
 	myself.setOptimization( TQPixmap::BestOptim );
@@ -148,7 +148,7 @@ void board_2d::drawMove( const ChessMove &chessMove, const bool &reverse )
 		TQTimer::singleShot( 0, this, TQ_SLOT( updateSprites() ) );
 		sprite *spritePtr = new sprite;
 		spritePtr->Steps = 1;
-		spritePtr->Restore = FALSE;
+		spritePtr->Restore = false;
 		spritePtr->POSITION_Origin = fromPtr;
 		spritePtr->POSITION_Destination = toPtr;
 		spritePtr->POSITION_TargetTaken = takenPtr;
@@ -180,7 +180,7 @@ void board_2d::drawMove( const ChessMove &chessMove, const bool &reverse )
 	/* Draw the originating position */
 	drawPosition( fromPtr );
 
-	if( TQString( chessMove.SAN ).contains( "o-o", FALSE ) )
+	if( TQString( chessMove.SAN ).contains( "o-o", false ) )
 	{
 		/* This is a castle */
 		ChessMove newMove;
@@ -188,7 +188,7 @@ void board_2d::drawMove( const ChessMove &chessMove, const bool &reverse )
 		newMove.fromRank = chessMove.fromRank;
 		newMove.toRank = chessMove.toRank;
 		newMove.ManTaken = Null;
-		if( TQString( chessMove.SAN ).contains( "o-o-o", FALSE ) )
+		if( TQString( chessMove.SAN ).contains( "o-o-o", false ) )
 		{
 			/* Queenside */
 			newMove.fromFile = 0;
@@ -202,7 +202,7 @@ void board_2d::drawMove( const ChessMove &chessMove, const bool &reverse )
 		}
 		drawMove( newMove, reverse );
 	}
-	lastMoveWasDrag = FALSE;
+	lastMoveWasDrag = false;
 }
 ///////////////////////////////////////
 //
@@ -211,8 +211,8 @@ void board_2d::drawMove( const ChessMove &chessMove, const bool &reverse )
 ///////////////////////////////////////
 void board_2d::resizeBoard( void )
 {
-	int size = 8 + ( 1 * ( myResource->ThemeBorder == TRUE ) );
-	init = FALSE;
+	int size = 8 + ( 1 * ( myResource->ThemeBorder == true ) );
+	init = false;
 
 	/* Resize myself */
 	myself.resize( myResource->ThemeSize * size, myResource->ThemeSize * size);
@@ -407,16 +407,16 @@ void board_2d::drawPosition( const int &pos )
 	{
 		case NOTE_HIGHLIGHT:	// Fall Through
 		case NOTE_SELECT:
-			bitBlt( &buffer, 0, 0, &cache->HighlightSelect, 0, 0, -1, -1, TQt::CopyROP, FALSE);
+			bitBlt( &buffer, 0, 0, &cache->HighlightSelect, 0, 0, -1, -1, TQt::CopyROP, false);
 			break;
 		case NOTE_MOVE:				// Fall Through
 		case NOTE_CASTLE:			// Fall Through
 		case NOTE_PAWN_DOUBLE:
-			bitBlt( &buffer, 0, 0, &cache->HighlightMove, 0, 0, -1, -1, TQt::CopyROP, FALSE);
+			bitBlt( &buffer, 0, 0, &cache->HighlightMove, 0, 0, -1, -1, TQt::CopyROP, false);
 			break;
 		case NOTE_ATTACK:			// Fall Through
 		case NOTE_ENPASSANT:
-			bitBlt( &buffer, 0, 0, &cache->HighlightAttack, 0, 0, -1, -1, TQt::CopyROP, FALSE);
+			bitBlt( &buffer, 0, 0, &cache->HighlightAttack, 0, 0, -1, -1, TQt::CopyROP, false);
 			break;
 		default:
 		break;
@@ -424,7 +424,7 @@ void board_2d::drawPosition( const int &pos )
 	if( !isSprite(pos) )
 	{
 		TQPixmap chessman = getChessman( pos );
-		bitBlt( &buffer, 0, 0, &chessman, 0, 0, -1, -1, TQt::CopyROP, FALSE);
+		bitBlt( &buffer, 0, 0, &chessman, 0, 0, -1, -1, TQt::CopyROP, false);
 	}
 	/* Now add this pixmap to the cache */
 	cache->add( cacheName, buffer );
@@ -504,7 +504,7 @@ void board_2d::mouseReleaseEvent( TQMouseEvent *event )
 		DragSprite = NULL;
 		drawPosition( tmp );
 		commit();
-		lastMoveWasDrag = TRUE;
+		lastMoveWasDrag = true;
 	}
 
 	if(event->button() == TQt::LeftButton)
@@ -560,7 +560,7 @@ void board_2d::mouseMoveEvent( TQMouseEvent *event )
 				/* Get the piece image and store it in dragPix */
 				DragSprite->PIXMAP_Sprite = getChessman( DragSprite->POSITION_Origin );
 				DragSprite->PIXMAP_FlipFrame.resize( DragSprite->PIXMAP_Sprite.size() );
-				DragSprite->Restore = FALSE;
+				DragSprite->Restore = false;
 			}
 			else
 				/* Not enough dragging */
@@ -696,9 +696,9 @@ void board_2d::drawSprites( void )
 	for( index = (signed int)sprites.count() - 1; index > -1; index-- )
 	{
 		spritePtr = sprites.at(index);
-		if( spritePtr->Restore == FALSE )
+		if( spritePtr->Restore == false )
 		{
-			spritePtr->Restore = TRUE;
+			spritePtr->Restore = true;
 		}
 		else
 		{
@@ -783,10 +783,10 @@ bool board_2d::isSprite( const int &pos )
 		sprite *tmpSprite = sprites.at( index );
 		if( tmpSprite->POSITION_Origin == pos )
 		{
-			return TRUE;
+			return true;
 		}
 	}
-	return FALSE;
+	return false;
 }
 ///////////////////////////////////////
 //
