@@ -26,7 +26,7 @@
 
 class Challenge_Graph_View : public TQCanvasView
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 	public:
