@@ -31,7 +31,7 @@ class TQLineEdit;
 
 class dlg_selectemail : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 										dlg_selectemail(TQWidget *parent, resource *Rsrc );
