@@ -26,11 +26,11 @@
 dlg_selectengine::dlg_selectengine(TQWidget *parent, resource *Rsrc, bool army ) :
 	KDialogBase(	parent,
 								0,
-								TRUE,
+								true,
 								i18n("Select Computer Player"),
 								Help|Ok,
 								Ok,
-								TRUE )
+								true )
 {
 	Resource = Rsrc;
 	Army = army;
@@ -41,14 +41,14 @@ dlg_selectengine::dlg_selectengine(TQWidget *parent, resource *Rsrc, bool army )
 															i18n( "Computer Players" ),
 															BOX_Parent );
 	COMBO_Engine = new KComboBox( BOX_Engine );
-	COMBO_Engine->setEditable( FALSE );
+	COMBO_Engine->setEditable( false );
 
 //	BOX_EngineHelper = new TQGroupBox( 1,
 //															TQt::Horizontal,
 //															i18n( "Computer Players' Helper" ),
 //															BOX_Parent );
 //	COMBO_EngineHelper = new KComboBox( BOX_Engine );
-//	COMBO_EngineHelper->setEditable( FALSE );
+//	COMBO_EngineHelper->setEditable( false );
 
 	buildEngineData();
 
@@ -81,8 +81,8 @@ dlg_selectengine::~dlg_selectengine()
 ///////////////////////////////////////
 void dlg_selectengine::buildEngineData( void )
 {
-	bool FLAG1(FALSE);
-//	bool FLAG2(FALSE);
+	bool FLAG1(false);
+//	bool FLAG2(false);
 	int Index(0);
 	TQStringList EngineList;
 	engineList::Iterator enginesIT;
@@ -126,14 +126,14 @@ void dlg_selectengine::buildEngineData( void )
 				if( COMBO_Engine->text(Index) == (*enginesIT).Name )
 				{
 					COMBO_Engine->setCurrentItem(Index);
-					FLAG1 = TRUE;
+					FLAG1 = true;
 				}
 //		if( (*enginesIT).CurrentRef & Engine2F )
 //			for( Index = 0; Index < COMBO_Engine->count(); Index++ )
 //				if( COMBO_EngineHelper->text(Index) == (*enginesIT).Name )
 //				{
 //					COMBO_EngineHelper->setCurrentItem(Index);
-//					FLAG2 = TRUE;
+//					FLAG2 = true;
 //				}
 	}
 
