@@ -35,7 +35,7 @@ class resource;
 
 class dlg_selectengine : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 										dlg_selectengine(TQWidget *parent, resource *Rsrc, bool army );
