@@ -21,11 +21,11 @@
 dlg_server::dlg_server(TQWidget *parent, const char *name, resource *Rsrc, TQString ItemName ) :
 	KDialogBase(	parent,
 								name,						
-								TRUE,
+								true,
 								i18n("Configure Server"),
 								Help|Ok|Apply|Cancel,
 								Ok,		
-								TRUE )
+								true )
 {
 	Resource = Rsrc;
 	Name = ItemName;
@@ -116,24 +116,24 @@ dlg_server::dlg_server(TQWidget *parent, const char *name, resource *Rsrc, TQStr
 	}
 	if( CHECK_StorePass->isChecked() )
 	{
-		EDIT_Password->setEnabled( TRUE );
-		EDIT_PasswordRetype->setEnabled( TRUE );
+		EDIT_Password->setEnabled( true );
+		EDIT_PasswordRetype->setEnabled( true );
 	}
 	else
 	{
-		EDIT_Password->setEnabled( FALSE );
-		EDIT_PasswordRetype->setEnabled( FALSE );
+		EDIT_Password->setEnabled( false );
+		EDIT_PasswordRetype->setEnabled( false );
 	}
 	/* Init the buttons */
-	showButtonCancel( TRUE );
-	showButtonOK( TRUE );
-	showButtonApply( TRUE );
-	showButton( Help, TRUE );
+	showButtonCancel( true );
+	showButtonOK( true );
+	showButtonApply( true );
+	showButton( Help, true );
 
-	enableButtonCancel( TRUE );
-	enableButtonOK( TRUE );
-	enableButtonApply( FALSE );
-	enableButton( Help, TRUE );
+	enableButtonCancel( true );
+	enableButtonOK( true );
+	enableButtonApply( false );
+	enableButton( Help, true );
 
 	setHelp( TQString( "configure-servers" ) );
 	/* Make Connections */
@@ -180,7 +180,7 @@ void dlg_server::slotApply( void )
 	(*serversIT).StorePass = CHECK_StorePass->isChecked();
 	(*serversIT).Timeseal = EDIT_Timeseal->text();
 	
-	enableButtonApply( FALSE );
+	enableButtonApply( false );
 }
 
 void dlg_server::slotCancel( void )
@@ -198,27 +198,27 @@ void dlg_server::slotLogFileDialog( void )
 																				TQString( "Find Log..." ) );
 	if( temp.isEmpty() ) return;
 	EDIT_LogFile->setText( temp );
-	enableButtonApply( TRUE );
+	enableButtonApply( true );
 }
 
 void dlg_server::slotEnableApply( const TQString& )
 {
-	enableButtonApply( TRUE );
+	enableButtonApply( true );
 }
 
 void dlg_server::slotStorePass( bool )
 {
 	if( CHECK_StorePass->isChecked() )
 	{
-		EDIT_Password->setEnabled( TRUE );
-		EDIT_PasswordRetype->setEnabled( TRUE );
+		EDIT_Password->setEnabled( true );
+		EDIT_PasswordRetype->setEnabled( true );
 	}
 	else
 	{
-		EDIT_Password->setEnabled( FALSE );
-		EDIT_PasswordRetype->setEnabled( FALSE );
+		EDIT_Password->setEnabled( false );
+		EDIT_PasswordRetype->setEnabled( false );
 	}
-	enableButtonApply( TRUE );
+	enableButtonApply( true );
 }
 ///////////////////////////////////////
 //
@@ -235,6 +235,6 @@ void dlg_server::slot_Timeseal( void )
 																				TQString( "Find Timeseal..." ) );
 	if( temp.isEmpty() ) return;
 	EDIT_Timeseal->setText( temp );
-	enableButtonApply( TRUE );
+	enableButtonApply( true );
 }
 
