@@ -39,7 +39,7 @@ class setPageGeneral;
 
 class dlg_settings : public KDialogBase
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 	public:
 													dlg_settings(TQWidget *parent=0, const char *name=0, resource *Rsrc=0);
