@@ -30,7 +30,7 @@ class resource;
 
 class KnightsTextView : public TQTextBrowser
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 	public:
 										KnightsTextView(TQWidget *parent, resource *Rsrc );
