@@ -23,7 +23,7 @@ setPageAudio::setPageAudio(TQWidget *parent, resource *Rsrc ) : TQVBoxLayout(par
 	Parent = parent;
 	Resource = Rsrc;
 	NewSounds = 0;
-	changeTheme = FALSE;
+	changeTheme = false;
 
 	BUTTON_enableAudio = new TQCheckBox( i18n( "Enable Audio" ), parent );
 	BUTTON_enableAudio->setChecked( Resource->OPTION_Audio );
@@ -78,7 +78,7 @@ void setPageAudio::slot_enableAudio( bool state )
 void setPageAudio::slot_currentTheme( int Index )
 {
 	NewSounds = Index;
-	changeTheme = TRUE;
+	changeTheme = true;
 	emit enableApply();
 }
 ///////////////////////////////////////
