@@ -36,7 +36,7 @@
 
 class setPageAudio : public TQVBoxLayout
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 	public:
 										setPageAudio(TQWidget *parent=0, resource *Rsrc=0);
