@@ -37,7 +37,7 @@
 
 class setPageEngines : public TQVBoxLayout
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 	public:
 						setPageEngines(TQWidget *parent=0, resource *Rsrc=0);
