@@ -36,7 +36,7 @@
 
 class setPageGeneral : public TQVBoxLayout
 {
-		Q_OBJECT
+		TQ_OBJECT
   
 	public:
 										setPageGeneral(TQWidget *parent=0, resource *Rsrc=0);
