@@ -32,7 +32,7 @@ class resource;
 
 class tab_SeekList : public TDEListView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	private:
