@@ -26,7 +26,7 @@
 
 class TabGrip : public TQWidget
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 	public:
 								TabGrip(TQWidget *parent=0, const char *name=0);
