@@ -73,7 +73,7 @@ TQButton* thinbuttons::create( int id )
 	newBut->ID = id;
 	buttons.append( newBut );
 
-	newButton->setToggleButton( TRUE );
+	newButton->setToggleButton( true );
 	newButton->setText( TQString("Match") );
 	newButton->show();
 
@@ -95,14 +95,14 @@ void thinbuttons::setButton( int id )
 		currentBut = buttons.at( Index );
 		if( currentBut->ID == id )
 		{
-			currentBut->button->setDown( TRUE );
+			currentBut->button->setDown( true );
 			if( currentBut->button->isToggleButton() )
 				if( currentBut->button->state() != TQButton::On )
 					currentBut->button->toggle();
 		}
 		else
 		{
-			currentBut->button->setDown( FALSE );
+			currentBut->button->setDown( false );
 			if( currentBut->button->isToggleButton() )
 				if( currentBut->button->state() == TQButton::On )
 					currentBut->button->toggle();
