@@ -35,7 +35,7 @@ struct Buttons
 
 class thinbuttons : public TQFrame
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 								thinbuttons(TQWidget *parent=0, const char *name=0, resource *Rsrc=0);
