@@ -36,7 +36,7 @@
 
 class wiz_setup : public KWizard
 {
-		Q_OBJECT
+		TQ_OBJECT
   
 		public:
 									wiz_setup( TQWidget *parent=0, const char *name=0, resource *Rsrc=0 );
